# LoadDensity

---

### Locust Wrapper a framework for stress testing and load testing

#### Features
* HTTP HTTPS stress testing and load testing
* Action FIle
* response compare
* CLI with action file
---
[![CircleCI](https://circleci.com/gh/JE-Chen/JE_LocustWrapper/tree/main.svg?style=svg)](https://circleci.com/gh/JE-Chen/JE_LocustWrapper/tree/main)
### Documentation
[![Documentation Status](https://readthedocs.org/projects/loaddensity/badge/?version=latest)](https://loaddensity.readthedocs.io/en/latest/?badge=latest)

https://loaddensity.readthedocs.io/en/latest/
---

## install 

```
pip install je_locust_wrapper
```

## require

```
python 3.7 or later  
```

* Test on
    * windows 10 ~ 11
    * osx 10.5 ~ 11 big sur
    * ubuntu 20.0.4
    * raspberry pi 3B+

| All test in test dir